@@ -84,12 +84,16 @@ class ReplyProcessor(object):
             self.wait_header()
 
 
-def parseCommand(*argv):
-    output = [["*",str(len(argv)),"\r\n"]] + [["$",str(len(p)),"\r\n",p,"\r\n"] for p in map(str,argv)]
-    return "".join(reduce(lambda i1,i2:i1+i2 ,output))
+def parse_command(*argv):
+    output = [["*", str(len(argv)), "\r\n"]] + [["$", str(len(p)), "\r\n", p, "\r\n"] for p in map(str, argv)]
+    return "".join(reduce(lambda i1, i2: i1+i2, output))
+
+
 
 class Subscriber(object):
     def __init__(self, host, port, db):
+        self.conn = None
+        self.send_conn = None
         self.conn_params = (host,port,db)
         self.reconnect(*self.conn_params)
         self.data_pool = []
@@ -99,7 +103,7 @@ class Subscriber(object):
         self.state_ok = False
 
     def listen_on(self, channels, callback):
-        self.conn.write(parseCommand("subscribe", *channels))
+        self.conn.write(parse_command("subscribe", *channels))
         self.callback = callback
         self.channels = channels
 
@@ -110,30 +114,30 @@ class Subscriber(object):
             pass
         self.conn = Connection(host, port)
         self.conn.regist_trigger(on_line)
-        self.conn.write(parseCommand("SELECT",str(db)))
+        self.conn.write(parse_command("SELECT", str(db)))
         self.conn.recive()
         self.send_conn = Connection(host, port)
         self.send_conn.regist_trigger(silent)
-        self.send_conn.write(parseCommand("SELECT",str(db)))
+        self.send_conn.write(parse_command("SELECT", str(db)))
         self.send_conn.recive()
         self.state_ok = True
 
 
-    def on_data(self,type, data):
-        if type == MULTI_BULK_REPLY and data[0] == "message":
+    def on_data(self, chunk_type, data):
+        if chunk_type == MULTI_BULK_REPLY and data[0] == "message":
             self.callback(data[1], data[2])
 
     def check_connection(self):
         if not self.state_ok:
             self.reconnect(*self.conn_params)
-            self.conn.write(parseCommand("subscribe", *self.channels))
+            self.conn.write(parse_command("subscribe", *self.channels))
 
 
     def notify_all(self, channel, message):
         if channel not in self.channels:
             return False
         try:
-            self.send_conn.write(parseCommand("publish", channel, tob(message)))
+            self.send_conn.write(parse_command("publish", channel, tob(message)))
         except StreamClosedError, e:
             logging.error(e.message)
             self.state_ok = False
